import setuptools
setuptools.setup(
    name = "perimetercalculator",
    version = "0.2",
    author = "Sayyam Sabadra",
    author_email = "sayyam9210@gmail.com",
    description = ("This is a perimeter finder which can finde the perimeter of any number given by user"),
    packages=setuptools.find_packages(),

    classifiers=[

        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)                         